==> hs-darcs-2.8.1_1.tbz: lib/ghc-7.4.1/cabal/darcs-2.8.1/register.sh <==
#!/bin/sh
echo 'name: darcs
version: 2.8.1
id: darcs-2.8.1-a0f09cda7174e79a207e835cd71a2746

license: GPL
copyright:
maintainer: <darcs-devel@darcs.net>
stability: Experimental
homepage: http://darcs.net/
package-url:
synopsis: a distributed, interactive, smart revision control system
description: Darcs is a free, open source revision control
             system. It is:
             .
             * Distributed: Every user has access to the full
             command set, removing boundaries between server and
             client or committer and non-committers.
             .
             * Interactive: Darcs is easy to learn and efficient to
             use because it asks you questions in response to
             simple commands, giving you choices in your work
             flow. You can choose to record one change in a file,
             while ignoring another. As you update from upstream,
             you can review each patch name, even the full "diff"
             for interesting patches.
             .
             * Smart: Originally developed by physicist David
             Roundy, darcs is based on a unique algebra of
             patches.
             .
             This smartness lets you respond to changing demands
             in ways that would otherwise not be possible. Learn
             more about spontaneous branches with darcs.
category: Development
author: David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
exposed: True
exposed-modules: CommandLine Crypt.SHA256 Darcs.Annotate
                 Darcs.ArgumentDefaults Darcs.Arguments Darcs.Bug Darcs.ColorPrinter
                 Darcs.Commands Darcs.Commands.Add Darcs.Commands.AmendRecord
                 Darcs.Commands.Annotate Darcs.Commands.Apply Darcs.CommandsAux
                 Darcs.Commands.Changes Darcs.Commands.Check Darcs.Commands.Convert
                 Darcs.Commands.Diff Darcs.Commands.Dist Darcs.Commands.Get
                 Darcs.Commands.GZCRCs Darcs.Commands.Help Darcs.Commands.Init
                 Darcs.Commands.MarkConflicts Darcs.Commands.Move
                 Darcs.Commands.Optimize Darcs.Commands.Pull Darcs.Commands.Push
                 Darcs.Commands.Put Darcs.Commands.Record Darcs.Commands.Remove
                 Darcs.Commands.Replace Darcs.Commands.Revert
                 Darcs.Commands.Rollback Darcs.Commands.Send Darcs.Commands.SetPref
                 Darcs.Commands.Show Darcs.Commands.ShowAuthors
                 Darcs.Commands.ShowBug Darcs.Commands.ShowContents
                 Darcs.Commands.ShowFiles Darcs.Commands.ShowIndex
                 Darcs.Commands.ShowRepo Darcs.Commands.ShowTags Darcs.Commands.Tag
                 Darcs.Commands.Test Darcs.Commands.TrackDown
                 Darcs.Commands.TransferMode Darcs.Commands.Util
                 Darcs.Commands.Unrecord Darcs.Commands.Unrevert
                 Darcs.Commands.WhatsNew Darcs.Compat Darcs.Diff Darcs.Email
                 Darcs.External Darcs.Flags Darcs.Global Darcs.IO Darcs.Lock
                 Darcs.Match Darcs.MonadProgress Darcs.Patch Darcs.Patch.Apply
                 Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
                 Darcs.Patch.Bracketed.Instances Darcs.Patch.Bundle
                 Darcs.Patch.Choices Darcs.Patch.Commute Darcs.Patch.Conflict
                 Darcs.Patch.ConflictMarking Darcs.Patch.Depends Darcs.Patch.Dummy
                 Darcs.Patch.Effect Darcs.Patch.FileName Darcs.Patch.FileHunk
                 Darcs.Patch.Format Darcs.Patch.Info Darcs.Patch.Inspect
                 Darcs.Patch.Invert Darcs.Patch.Match Darcs.Patch.MatchData
                 Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.OldDate
                 Darcs.Patch.PatchInfoAnd Darcs.Patch.Patchy
                 Darcs.Patch.Patchy.Instances Darcs.Patch.Permutations
                 Darcs.Patch.Prim Darcs.Patch.Prim.Class Darcs.Patch.Prim.V1
                 Darcs.Patch.Prim.V1.Apply Darcs.Patch.Prim.V1.Coalesce
                 Darcs.Patch.Prim.V1.Commute Darcs.Patch.Prim.V1.Core
                 Darcs.Patch.Prim.V1.Details Darcs.Patch.Prim.V1.Read
                 Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.V3
                 Darcs.Patch.Prim.V3.ObjectMap Darcs.Patch.Prim.V3.Apply
                 Darcs.Patch.Prim.V3.Coalesce Darcs.Patch.Prim.V3.Commute
                 Darcs.Patch.Prim.V3.Core Darcs.Patch.Prim.V3.Details
                 Darcs.Patch.Prim.V3.Read Darcs.Patch.Prim.V3.Show Darcs.Patch.Read
                 Darcs.Patch.ReadMonads Darcs.Patch.RegChars Darcs.Patch.Repair
                 Darcs.Patch.RepoPatch Darcs.Patch.Set Darcs.Patch.Show
                 Darcs.Patch.Split Darcs.Patch.Summary Darcs.Patch.SummaryData
                 Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
                 Darcs.Patch.Viewing Darcs.Patch.V1 Darcs.Patch.V1.Apply
                 Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Read
                 Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing Darcs.Patch.V2
                 Darcs.Patch.V2.Non Darcs.Patch.V2.Real Darcs.PrintPatch
                 Darcs.ProgressPatches Darcs.RemoteApply Darcs.RepoPath
                 Darcs.Repository Darcs.Repository.ApplyPatches
                 Darcs.Repository.Cache Darcs.Repository.Format
                 Darcs.Repository.HashedIO Darcs.Repository.HashedRepo
                 Darcs.Repository.Internal Darcs.Repository.LowLevel
                 Darcs.Repository.Merge Darcs.Repository.InternalTypes
                 Darcs.Repository.Motd Darcs.Repository.Old Darcs.Repository.Prefs
                 Darcs.Repository.Repair Darcs.Repository.State Darcs.Resolution
                 Darcs.RunCommand Darcs.SelectChanges Darcs.SignalHandler Darcs.Ssh
                 Darcs.Test Darcs.TheCommands Darcs.URL Darcs.Utils
                 Darcs.Witnesses.Eq Darcs.Witnesses.Ordered Darcs.Witnesses.Sealed
                 Darcs.Witnesses.Show Darcs.Witnesses.Unsafe Darcs.Witnesses.WZipper
                 DateMatcher English Exec ByteStringUtils IsoDate Lcs Printer
                 Progress Ratified SHA1 URL URL.Request URL.HTTP Workaround
hidden-modules: Version URL.Curl
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/darcs-2.8.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/darcs-2.8.1
              /usr/local/lib
hs-libraries: HSdarcs-2.8.1
extra-libraries: curl
extra-ghci-libraries:
include-dirs: /usr/local/include
includes: curl/curl.h
depends: array-0.4.0.0-59d1cc0e7979167b002f021942d60f46
         base-4.5.0.0-3459bca6d8e46666b517e8bb2e033728
         bytestring-0.9.2.1-6ff76798e80a342ff74a1c8bcb3f4124
         containers-0.4.2.1-cfc6420ecc2194c9ed977b06bdfd9e69
         directory-1.1.0.2-265c831825d90ce2ca097745b0e621c1
         extensible-exceptions-0.1.1.4-d27a1ac47e54880cae007cceceb41580
         filepath-1.3.0.0-973f5e9fbed93e25cbe66dfeb6b99ad9
         hashed-storage-0.5.9-27e46f938ecb7c9a684153e532ac211e
         haskeline-0.6.4.7-a4eb21d81dc61cd5d3621f9cccec98c2
         html-1.0.1.2-d026516aed783055d4f46ccc071c7148
         mtl-2.1.1-801101765c9185fec3b8dbd5355f5550
         old-time-1.1.0.0-b77788a065c86ada9ba279afa5e04576
         parsec-3.1.2-3f17b6bc81721b0dea43d218225f6b9f
         process-1.1.0.1-18dadd8ad5fc640f55a7afdc7aace500
         random-1.0.1.1-7f9342c90214b9289fdaf20c9e2f867f
         regex-compat-0.95.1-cab6a53bc04a333f26d71b520cdf2074
         tar-0.4.0.0-738ea074f4da6bc26429fc5be6697bc6
         text-0.11.2.0-4b4e60de19cb46704c87afc38bab5d9f
         unix-2.5.1.0-a532dbbf21e94309c6605a5babf5c531
         vector-0.9.1-04dd5c58c224b03a4dc90091cf93a01d
         zlib-0.5.3.3-25bc90418de17a311a72450ebca404a8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/darcs-2.8.1/html/darcs.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/darcs-2.8.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-darcs-2.8.4.tbz: lib/ghc-7.4.2/cabal/darcs-2.8.4/register.sh <==
#!/bin/sh
echo 'name: darcs
version: 2.8.4
id: darcs-2.8.4-05d6f7dd292cb5060ba9d70491b4aef2

license: GPL
copyright:
maintainer: <darcs-devel@darcs.net>
stability: Experimental
homepage: http://darcs.net/
package-url:
synopsis: a distributed, interactive, smart revision control system
description: Darcs is a free, open source revision control
             system. It is:
             .
             * Distributed: Every user has access to the full
             command set, removing boundaries between server and
             client or committer and non-committers.
             .
             * Interactive: Darcs is easy to learn and efficient to
             use because it asks you questions in response to
             simple commands, giving you choices in your work
             flow. You can choose to record one change in a file,
             while ignoring another. As you update from upstream,
             you can review each patch name, even the full "diff"
             for interesting patches.
             .
             * Smart: Originally developed by physicist David
             Roundy, darcs is based on a unique algebra of
             patches.
             .
             This smartness lets you respond to changing demands
             in ways that would otherwise not be possible. Learn
             more about spontaneous branches with darcs.
category: Development
author: David Roundy <droundy@darcs.net>, <darcs-devel@darcs.net>
exposed: True
exposed-modules: CommandLine Crypt.SHA256 Darcs.Annotate
                 Darcs.ArgumentDefaults Darcs.Arguments Darcs.Bug Darcs.ColorPrinter
                 Darcs.Commands Darcs.Commands.Add Darcs.Commands.AmendRecord
                 Darcs.Commands.Annotate Darcs.Commands.Apply Darcs.CommandsAux
                 Darcs.Commands.Changes Darcs.Commands.Check Darcs.Commands.Convert
                 Darcs.Commands.Diff Darcs.Commands.Dist Darcs.Commands.Get
                 Darcs.Commands.GZCRCs Darcs.Commands.Help Darcs.Commands.Init
                 Darcs.Commands.MarkConflicts Darcs.Commands.Move
                 Darcs.Commands.Optimize Darcs.Commands.Pull Darcs.Commands.Push
                 Darcs.Commands.Put Darcs.Commands.Record Darcs.Commands.Remove
                 Darcs.Commands.Replace Darcs.Commands.Revert
                 Darcs.Commands.Rollback Darcs.Commands.Send Darcs.Commands.SetPref
                 Darcs.Commands.Show Darcs.Commands.ShowAuthors
                 Darcs.Commands.ShowBug Darcs.Commands.ShowContents
                 Darcs.Commands.ShowFiles Darcs.Commands.ShowIndex
                 Darcs.Commands.ShowRepo Darcs.Commands.ShowTags Darcs.Commands.Tag
                 Darcs.Commands.Test Darcs.Commands.TrackDown
                 Darcs.Commands.TransferMode Darcs.Commands.Util
                 Darcs.Commands.Unrecord Darcs.Commands.Unrevert
                 Darcs.Commands.WhatsNew Darcs.Compat Darcs.Diff Darcs.Email
                 Darcs.External Darcs.Flags Darcs.Global Darcs.IO Darcs.Lock
                 Darcs.Match Darcs.MonadProgress Darcs.Patch Darcs.Patch.Apply
                 Darcs.Patch.ApplyMonad Darcs.Patch.Bracketed
                 Darcs.Patch.Bracketed.Instances Darcs.Patch.Bundle
                 Darcs.Patch.Choices Darcs.Patch.Commute Darcs.Patch.Conflict
                 Darcs.Patch.ConflictMarking Darcs.Patch.Depends Darcs.Patch.Dummy
                 Darcs.Patch.Effect Darcs.Patch.FileName Darcs.Patch.FileHunk
                 Darcs.Patch.Format Darcs.Patch.Info Darcs.Patch.Inspect
                 Darcs.Patch.Invert Darcs.Patch.Match Darcs.Patch.MatchData
                 Darcs.Patch.Merge Darcs.Patch.Named Darcs.Patch.OldDate
                 Darcs.Patch.PatchInfoAnd Darcs.Patch.Patchy
                 Darcs.Patch.Patchy.Instances Darcs.Patch.Permutations
                 Darcs.Patch.Prim Darcs.Patch.Prim.Class Darcs.Patch.Prim.V1
                 Darcs.Patch.Prim.V1.Apply Darcs.Patch.Prim.V1.Coalesce
                 Darcs.Patch.Prim.V1.Commute Darcs.Patch.Prim.V1.Core
                 Darcs.Patch.Prim.V1.Details Darcs.Patch.Prim.V1.Read
                 Darcs.Patch.Prim.V1.Show Darcs.Patch.Prim.V3
                 Darcs.Patch.Prim.V3.ObjectMap Darcs.Patch.Prim.V3.Apply
                 Darcs.Patch.Prim.V3.Coalesce Darcs.Patch.Prim.V3.Commute
                 Darcs.Patch.Prim.V3.Core Darcs.Patch.Prim.V3.Details
                 Darcs.Patch.Prim.V3.Read Darcs.Patch.Prim.V3.Show Darcs.Patch.Read
                 Darcs.Patch.ReadMonads Darcs.Patch.RegChars Darcs.Patch.Repair
                 Darcs.Patch.RepoPatch Darcs.Patch.Set Darcs.Patch.Show
                 Darcs.Patch.Split Darcs.Patch.Summary Darcs.Patch.SummaryData
                 Darcs.Patch.TokenReplace Darcs.Patch.TouchesFiles
                 Darcs.Patch.Viewing Darcs.Patch.V1 Darcs.Patch.V1.Apply
                 Darcs.Patch.V1.Commute Darcs.Patch.V1.Core Darcs.Patch.V1.Read
                 Darcs.Patch.V1.Show Darcs.Patch.V1.Viewing Darcs.Patch.V2
                 Darcs.Patch.V2.Non Darcs.Patch.V2.Real Darcs.PrintPatch
                 Darcs.ProgressPatches Darcs.RemoteApply Darcs.RepoPath
                 Darcs.Repository Darcs.Repository.ApplyPatches
                 Darcs.Repository.Cache Darcs.Repository.Format
                 Darcs.Repository.HashedIO Darcs.Repository.HashedRepo
                 Darcs.Repository.Internal Darcs.Repository.LowLevel
                 Darcs.Repository.Merge Darcs.Repository.InternalTypes
                 Darcs.Repository.Motd Darcs.Repository.Old Darcs.Repository.Prefs
                 Darcs.Repository.Repair Darcs.Repository.State Darcs.Resolution
                 Darcs.RunCommand Darcs.SelectChanges Darcs.SignalHandler Darcs.Ssh
                 Darcs.Test Darcs.TheCommands Darcs.URL Darcs.Utils
                 Darcs.Witnesses.Eq Darcs.Witnesses.Ordered Darcs.Witnesses.Sealed
                 Darcs.Witnesses.Show Darcs.Witnesses.Unsafe Darcs.Witnesses.WZipper
                 DateMatcher Encoding English Exec ByteStringUtils IsoDate Lcs
                 Printer Progress Ratified SHA1 URL URL.Request URL.HTTP Workaround
hidden-modules: Encoding.IConv Version URL.Curl
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/darcs-2.8.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/darcs-2.8.4
              /usr/local/lib
hs-libraries: HSdarcs-2.8.4
extra-libraries: iconv curl
extra-ghci-libraries:
include-dirs: /usr/local/include
includes: curl/curl.h
depends: array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         directory-1.1.0.2-9e375ee7bfb1a0ae28bfd926af73e15a
         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
         hashed-storage-0.5.10-5c280c111d360054efd0096bb1e9c979
         haskeline-0.7.0.3-9bd681967de153a9b159ba82d3bdbe03
         html-1.0.1.2-72c7cb79e3ebad8847cc8b2143b83c63
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
         old-time-1.1.0.0-703543375fafbcbe67bc51a758e84f10
         parsec-3.1.3-5f7c2da354dce0be86cf682bae60efdd
         process-1.1.0.1-608c248c1528f46eb960a08cead77291
         random-1.0.1.1-c58cc32eea7e1ff248e803433efc4a71
         regex-compat-0.95.1-7e067d726f01aa046c9d3207860a884e
         tar-0.4.0.1-778fea159d62b7bb5ce870356cc09b3a
         text-0.11.2.3-116e588a2afe9f305204001245768a0d
         unix-2.5.1.1-56b0b11ddb32a213f6d73865d709e743
         utf8-string-0.3.7-04a3142a70bb175cd8cce44559228e78
         vector-0.10.0.1-3450daae3d9f2092020075d05481123c
         zlib-0.5.4.0-f9a7b27d857d3e506b8524567650abc8
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/darcs-2.8.4/html/darcs.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/darcs-2.8.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
